#pragma region Project Includes
#include "stdafx.h"
#include "ControlCenter.h"
#pragma endregion

#include "TMutex.h"
#include "TMethodCall.h"
#include "TInterpreter.h"

ControlCenter::ControlCenter()
{
	;
}


ControlCenter::~ControlCenter()
{
	delete stDataStructure;
}

bool ControlCenter::ControlCenterInitialise()
{
#pragma region Control Center Initialisation
	//Initialise the variables for an exchange:
	stDataStructure = new DataStructure;
	stDataStructure->Exposure = 0;
	stDataStructure->Gain = 0;
	stDataStructure->SensorType = 0;
	stDataStructure->pHight = 0;
	stDataStructure->pWidth = 0;
	stDataStructure->pData = nullptr;

	//Log that Control Center was initialised succesfully:
	printf("CC:> Control Center Initialised\n"); //#LOG
#pragma endregion	

#pragma region Core Modules Initialisation	

	// Try to Initialise the Sensor Module:
#ifdef _SENSOR_MANAGER
	try
	{
		if (sensorManager = new SensorManager())
		{ //#LEAK
			sensorManager->SensorManagerInitialise();
			printf("CC:> Sensor Manager Initialised\n");
		}; //#LOG
	}
	catch (int e)
	{
		printf("CC:> ERROR: Sensor Manager Initialisation FAILED\n"); //#LOG
	}
#endif
	// Try to Initialise the Rig Module:
#ifdef _RIG_MANAGER_MANAGER
	try
	{
		printf("CC:> Rig Manager Initialised\n"); //#LOG
	}
	catch (int e)
	{
		printf("CC:> ERROR: Rig Manager Initialisation FAILED\n"); //#LOG
	}
#endif

	// Try to Initialise the Visualisation Module:
#ifdef _VISUALISATION_MANAGER
	try
	{
		printf("CC:> Visualisation Manager Initialised\n"); //#LOGG
	}
	catch (int e)
	{
		printf("CC:> ERROR: Visualisation Manager Initialisation FAILED\n"); //#LOG
	}
#endif

	return true;
}

bool ControlCenter::SnapShot()
{
	// Was initialised in ControlCenter::ControlCenterInitialise()
	sensorManager->memDestMutex->Lock();

	sensorManager->memDestMutex->UnLock();
	if (!sensorManager)
	{
		printf("CC:> ERROR: Snapshot FAILD\n");//#LOG
		return false;//#LOG
	}
	if (!(sensorManager->AquireFrame()))
	{
		printf("CC:> ERROR: Snapshot FAILD\n");//#LOG
		return false(); //#LOG
	}
	printf("CC:> Snapshot Taken\n");//#LOG
	
	return true;
}

bool ControlCenter::BeginMonitoring()
{
	
	sensorManager->BeginMonitoringThread();
	return true;
}

bool ControlCenter::StopMonitoring()
{
	sensorManager->StopMonitoringThread();
	return true;
}